burrito
=======

|Build Status| |Coverage Status|

burrito, canonically pronounced *boar-eee-toe*, is a Python framework for
wrapping and controlling command-line applications.

What's with the name?
---------------------

This tool allows developers to wrap command-line applications, just as burritos
wrap delicious foods. Both hide the potentially unsightly details.

Installation
------------

To install burrito::

    pip install burrito

Running the tests
-----------------

To run burrito's unit tests::

    nosetests

The pre-history of burrito
--------------------------

burrito is derived from the `application controller framework <http://pycogent.org/examples/application_controller_framework.html>`__
code, which was originally added to `PyCogent <http://www.pycogent.org>`__ and
later moved to `scikit-bio <http://scikit-bio.org>`__. The contributors and/or
copyright holders have agreed to make the code they wrote for PyCogent
available under the BSD license. The original authors of the application
controller framework code in PyCogent are Greg Caporaso
(`@gregcaporaso <https://github.com/gregcaporaso>`__), Sandra Smit,
Micah Hamady, and Rob Knight (`@rob-knight <https://github.com/rob-knight>`__).

.. |Build Status| image:: https://travis-ci.org/biocore/burrito.svg?branch=master
   :target: https://travis-ci.org/biocore/burrito
.. |Coverage Status| image:: https://coveralls.io/repos/biocore/burrito/badge.png
   :target: https://coveralls.io/r/biocore/burrito
